app

package
v0.0.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 28, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InstallGlobalInputCapture

func InstallGlobalInputCapture(
	app *tview.Application,
	headerConfig *model.HeaderConfig,
	inputRouter *controller.InputRouter,
	navController *controller.NavigationController,
)

InstallGlobalInputCapture installs the global keyboard handler (header toggle, router dispatch).

func NewApp

func NewApp() *tview.Application

NewApp creates a tview application.

func Run

func Run(app *tview.Application, rootLayout *view.RootLayout) error

Run runs the tview application. Returns an error if the application fails to run.

func SetupSignalHandler

func SetupSignalHandler(app *tview.Application)

SetupSignalHandler registers a signal handler that stops the application on SIGINT or SIGTERM.

Types

This section is empty.

Jump to