Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InstallGlobalInputCapture ¶
func InstallGlobalInputCapture( app *tview.Application, headerConfig *model.HeaderConfig, inputRouter *controller.InputRouter, navController *controller.NavigationController, )
InstallGlobalInputCapture installs the global keyboard handler (header toggle, router dispatch).
func Run ¶
func Run(app *tview.Application, rootLayout *view.RootLayout) error
Run runs the tview application. Returns an error if the application fails to run.
func SetupSignalHandler ¶
func SetupSignalHandler(app *tview.Application)
SetupSignalHandler registers a signal handler that stops the application on SIGINT or SIGTERM.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.