Documentation
¶
Index ¶
- func ClampRGB(value int) int
- func DarkenRGB(rgb [3]int, ratio float64) [3]int
- func GradientFromColor(primary tcell.Color, ratio float64, fallback config.Gradient) config.Gradient
- func GradientFromColorVibrant(primary tcell.Color, boost float64, fallback config.Gradient) config.Gradient
- func InterpolateColor(gradient config.Gradient, t float64) tcell.Color
- func InterpolateRGB(from, to [3]int, t float64) [3]int
- func LightenRGB(rgb [3]int, ratio float64) [3]int
- func RenderAdaptiveGradientText(text string, gradient config.Gradient, fallbackColor tcell.Color) string
- func RenderGradientText(text string, gradient config.Gradient) string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GradientFromColor ¶
func GradientFromColor(primary tcell.Color, ratio float64, fallback config.Gradient) config.Gradient
GradientFromColor derives a gradient by lightening the base color.
func GradientFromColorVibrant ¶
func GradientFromColorVibrant(primary tcell.Color, boost float64, fallback config.Gradient) config.Gradient
GradientFromColorVibrant derives a vibrant gradient by boosting RGB values.
func InterpolateColor ¶
InterpolateColor is a convenience wrapper returning tcell.Color.
func InterpolateRGB ¶
InterpolateRGB performs linear RGB interpolation with proper rounding. t should be in [0, 1] range (automatically clamped).
func LightenRGB ¶
LightenRGB increases brightness toward white by ratio [0, 1].
func RenderAdaptiveGradientText ¶
func RenderAdaptiveGradientText(text string, gradient config.Gradient, fallbackColor tcell.Color) string
RenderAdaptiveGradientText renders text with gradient or solid color based on config.UseGradients. When gradients are disabled, uses the gradient's end color as a solid color fallback.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.